URW
===

A Pakistani language random word generator.


Details
-------

Uses a predefined set of words for enumeration.


Package Usage
-------------

from rwp import rwp

\# show a phrase made of n=2 random words

rwp.show_random_words(2)
